@@ -3,7 +3,7 @@ package Dist::Zilla::Starter;
 use strict;
 use warnings;
 
-our $VERSION = 'v4.0.1';
+our $VERSION = 'v5.0.0';
 
 1;
 
@@ -310,7 +310,7 @@ will be the alias for that instance of the plugin; otherwise, the alias is the
 same as the section name. This is important because each section in an INI file
 is unique, and because plugins are looked up by this name, so to include the
 same plugin twice, at least one of them must have an alias. Additionally, some
-plugins use the alias to set configuration, but this a bit overly magical.
+plugins use the alias to set configuration, but this is a bit overly magical.
 
   [MyPlugin / FirstPlugin]
   [MyPlugin / SecondPlugin]
@@ -507,7 +507,8 @@ process.
 
 In the L<-FilePruner|Dist::Zilla::Role::FilePruner> phase, gathered files may
 be removed from the distribution. In C<[@Starter]> this is handled by the
-plugins L<[PruneCruft]|Dist::Zilla::Plugin::PruneCruft> and
+plugins L<[PruneCruft]|Dist::Zilla::Plugin::PruneCruft>,
+L<[PruneFiles]|Dist::Zilla::Plugin::PruneFiles>, and
 L<[ManifestSkip]|Dist::Zilla::Plugin::ManifestSkip>. This phase is also
 executed by the minting process.
 
